@@ -14,11 +14,8 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-#ifndef __AISCM_SAMPLES_HELPERS_H
-#define __AISCM_SAMPLES_HELPERS_H
-
+#pragma once
 #include <libguile.h>
 
-void pointers_from_offsets(uint8_t *pointer, int64_t offsets[], uint8_t *pointers[], int n);
 
-#endif
+void pointers_from_offsets(uint8_t *pointer, int64_t offsets[], uint8_t *pointers[], int n);
