@@ -20,10 +20,14 @@
 void init_ringbuffer_tests(void);
 void init_ffmpeg_helpers_tests(void);
 void init_jit_tests(void);
+void init_util_helpers_tests(void);
+void init_samples_helpers_tests(void);
 
 void init_tests(void)
 {
   init_ringbuffer_tests();
   init_ffmpeg_helpers_tests();
   init_jit_tests();
+  init_util_helpers_tests();
+  init_samples_helpers_tests();
 }
