@@ -14,11 +14,10 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-#ifndef __AISCM_IMAGE_HELPERS_H
-#define __AISCM_IMAGE_HELPERS_H
-
+#pragma once
 #include <libguile.h>
 
+
 #define SCM_FUNC(ptr) ((void *)(size_t)ptr)
 
 void scm_to_int_array(SCM source, int32_t dest[]);
@@ -26,6 +25,3 @@ void scm_to_int_array(SCM source, int32_t dest[]);
 void scm_to_long_array(SCM source, int64_t dest[]);
 
 SCM clean_up_on_failure(SCM scm_object, SCM (*cleanup_method)(SCM), SCM scm_fun, SCM scm_arg);
-
-#endif
-
