@@ -1,5 +1,5 @@
 (use-modules (oop goops) (aiscm ffmpeg) (aiscm pulse))
 (define audio (open-ffmpeg-input "test.mp3"))
 (define output (make <pulse-play> #:rate (rate audio) #:channels (channels audio) #:typecode (typecode audio)))
-(write-audio (lambda _ (read-audio audio)) output)
+(write-audio (lambda _ (read-audio audio (rate audio))) output)
 (drain output)
