@@ -4,7 +4,7 @@
 (define pulse (make <pulse-play> #:rate (rate video) #:channels (channels video) #:typecode (typecode video) #:latency 0.1))
 (show
   (lambda (dsp)
-    (while (< (audio-pts video) (+ (video-pts video) 0.2)) (write-audio (or (read-audio video) (break)) pulse))
-    (format #t "video pts = ~8,2f, audio-pts = ~8,2f, latency = ~8,2f~&" (video-pts video) (audio-pts video) (latency pulse))
+    (while (< (audio-pts video) (+ (video-pts video) 0.2)) (write-audio (or (read-audio video (/ (rate video) 10)) (break)) pulse))
+    (format #t "video pts = ~8,2f, audio-pts = ~8,2f, latency = ~8,2f~%" (video-pts video) (audio-pts video) (latency pulse))
     (synchronise (read-image video) (- (video-pts video) (- (audio-pts video) (latency pulse))) (event-loop dsp))))
 (drain pulse)
