@@ -4,5 +4,5 @@
 (define time (clock))
 (show
   (lambda (dsp)
-    (format #t "video pts = ~8,2f, clock = ~8,2f~&" (video-pts video) (elapsed time))
+    (format #t "video pts = ~8,2f, clock = ~8,2f~%" (video-pts video) (elapsed time))
     (synchronise (read-image video) (- (video-pts video) (elapsed time)) (event-loop dsp))))
