@@ -7,5 +7,5 @@
 ;255
 (+ (rgb 2 3 5) 1)
 ;(rgb 3 4 6)
-(= (rgb 2 2 2) 2)
+(== (rgb 2 2 2) 2)
 ;#t
